@@ -86,8 +86,10 @@ def aux_logger(in_name: str):
     in_name = in_name.split('.', maxsplit=1)
     in_name = in_name[-1]
     name_length = len(in_name)
-    if name_length > 34:
-        while name_length > 31:
+    if name_length > 33:
+        while name_length > 30:
+            if '.' not in in_name:
+                break
             in_name = in_name.split('.', maxsplit=1)
             in_name = in_name[-1]
             name_length = len(in_name)
@@ -150,7 +152,7 @@ class CustomFormatter(logging.Formatter):
 
 def _each_run_file_rotate_handler(in_file_name, in_back_up):
     _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
-    formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}|{threadName:^14}|{lineno:^7}| {name:<35}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime} |{levelname:^13}|{threadName:^14}|{lineno:^7}| {name:<39}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
     handler = handlers.RotatingFileHandler(in_file_name, mode='a', backupCount=in_back_up, maxBytes=10 * (1024 * 1024))
     handler.namer = std_namer
     handler.setFormatter(formatter)
@@ -158,8 +160,8 @@ def _each_run_file_rotate_handler(in_file_name, in_back_up):
 
 
 def _stdout_handler():
-    _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
-    formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}|{threadName:^14}|{lineno:^7}| {name:<35}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
+    _date_format = DATEFORMAT_DEV
+    formatter = CustomFormatter(fmt='{asctime} |{levelname:^13}| {name:<39}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
     # formatter = logging.Formatter(fmt='[{asctime}][{levelname:^7}][{name:<30}][{funcName:^25}] --> {message}', datefmt=_date_format, style='{')
     handler = logging.StreamHandler()
     handler.setFormatter(formatter)
